import pandas as pd

from edabox.core.utils import process_frame
from edabox.core.utils import process_feature
from edabox.core import DataBox

# module level doc-string
__doc__ = """
edabox - a library for Python to gain insights into datasets
WORK IN PROGRESS
"""

__all__ = [
    "DataBox",
    "read_csv",
    "read_excel",
    "read_frame",
    "process_frame",
    "process_feature"
]